@@ -17,10 +17,10 @@ import time
 
 import iso8601
 
+from openstack.cloud import _network_common
 from openstack.cloud import _utils
 from openstack.cloud import exc
 from openstack.cloud import meta
-from openstack.compute.v2._proxy import Proxy
 from openstack.compute.v2 import server as _server
 from openstack import exceptions
 from openstack import utils
@@ -68,8 +68,7 @@ def _pop_or_get(resource, key, default, strict):
         return resource.get(key, default)
 
 
-class ComputeCloudMixin:
-    compute: Proxy
+class ComputeCloudMixin(_network_common.NetworkCommonCloudMixin):
 
     @property
     def _compute_region(self):
@@ -115,13 +114,6 @@ class ComputeCloudMixin:
             )
         )
 
-    def _nova_extensions(self):
-        extensions = {e.alias for e in self.compute.extensions()}
-        return extensions
-
-    def _has_nova_extension(self, extension_name):
-        return extension_name in self._nova_extensions()
-
     def search_keypairs(self, name_or_id=None, filters=None):
         """Search keypairs.
 
@@ -324,7 +316,7 @@ class ComputeCloudMixin:
             try:
                 self.compute.remove_security_group_from_server(server, sg)
 
-            except exceptions.ResourceNotFound:
+            except exceptions.NotFoundException:
                 # NOTE(jamielennox): Is this ok? If we remove something that
                 # isn't present should we just conclude job done or is that an
                 # error? Nova returns ok if you try to add a group twice.
@@ -560,7 +552,7 @@ class ComputeCloudMixin:
         try:
             server = self.compute.get_server(id)
             return meta.add_server_interfaces(self, server)
-        except exceptions.ResourceNotFound:
+        except exceptions.NotFoundException:
             return None
 
     def get_server_group(self, name_or_id=None, filters=None):
@@ -611,7 +603,7 @@ class ComputeCloudMixin:
         """
         try:
             self.compute.delete_keypair(name, ignore_missing=False)
-        except exceptions.ResourceNotFound:
+        except exceptions.NotFoundException:
             self.log.debug("Keypair %s not found for deleting", name)
             return False
         return True
@@ -1398,7 +1390,7 @@ class ComputeCloudMixin:
 
         try:
             self.compute.delete_server(server)
-        except exceptions.ResourceNotFound:
+        except exceptions.NotFoundException:
             return False
         except Exception:
             raise
@@ -1707,7 +1699,7 @@ class ComputeCloudMixin:
         try:
             self.compute.delete_aggregate(name_or_id, ignore_missing=False)
             return True
-        except exceptions.ResourceNotFound:
+        except exceptions.NotFoundException:
             self.log.debug("Aggregate %s not found for deleting", name_or_id)
             return False
 
