@@ -16,7 +16,7 @@ import ipaddress
 import socket
 
 from openstack import _log
-from openstack.cloud import exc
+from openstack import exceptions
 from openstack import utils
 
 
@@ -39,9 +39,8 @@ def find_nova_interfaces(
                     # ext_tag is specified, but this interface has no tag
                     # We could actually return right away as this means that
                     # this cloud doesn't support OS-EXT-IPS. Nevertheless,
-                    # it would be better to perform an explicit check. e.g.:
-                    #   cloud._has_nova_extension('OS-EXT-IPS')
-                    # But this needs cloud to be passed to this function.
+                    # it would be better to perform an explicit check
+                    # but this needs cloud to be passed to this function.
                     continue
                 elif interface_spec['OS-EXT-IPS:type'] != ext_tag:
                     # Type doesn't match, continue with next one
@@ -52,9 +51,8 @@ def find_nova_interfaces(
                     # mac_addr is specified, but this interface has no mac_addr
                     # We could actually return right away as this means that
                     # this cloud doesn't support OS-EXT-IPS-MAC. Nevertheless,
-                    # it would be better to perform an explicit check. e.g.:
-                    #   cloud._has_nova_extension('OS-EXT-IPS-MAC')
-                    # But this needs cloud to be passed to this function.
+                    # it would be better to perform an explicit check
+                    # but this needs cloud to be passed to this function.
                     continue
                 elif interface_spec['OS-EXT-IPS-MAC:mac_addr'] != mac_addr:
                     # MAC doesn't match, continue with next one
@@ -265,7 +263,7 @@ def find_best_address(addresses, public=False, cloud_public=True):
                             connect_socket.settimeout(1)
                             connect_socket.connect(sa)
                             return address
-                    except socket.error:
+                    except OSError:
                         # Sometimes a "no route to address" type error
                         # will fail fast, but can often come alive
                         # when retried.
@@ -370,7 +368,7 @@ def get_groups_from_server(cloud, server, server_vars):
     groups.append(region)
 
     # And one by cloud_region
-    groups.append("%s_%s" % (cloud_name, region))
+    groups.append(f"{cloud_name}_{region}")
 
     # Check if group metadata key in servers' metadata
     group = server['metadata'].get('group')
@@ -385,17 +383,17 @@ def get_groups_from_server(cloud, server, server_vars):
 
     for key in ('flavor', 'image'):
         if 'name' in server_vars[key]:
-            groups.append('%s-%s' % (key, server_vars[key]['name']))
+            groups.append('{}-{}'.format(key, server_vars[key]['name']))
 
     for key, value in iter(server['metadata'].items()):
-        groups.append('meta-%s_%s' % (key, value))
+        groups.append(f'meta-{key}_{value}')
 
     az = server_vars.get('az', None)
     if az:
         # Make groups for az, region_az and cloud_region_az
         groups.append(az)
-        groups.append('%s_%s' % (region, az))
-        groups.append('%s_%s_%s' % (cloud.name, region, az))
+        groups.append(f'{region}_{az}')
+        groups.append(f'{cloud.name}_{region}_{az}')
     return groups
 
 
@@ -452,7 +450,7 @@ def _get_supplemental_addresses(cloud, server):
                         server['addresses'][fixed_net].append(
                             _make_address_dict(fip, port)
                         )
-    except exc.OpenStackCloudException:
+    except exceptions.SDKException:
         # If something goes wrong with a cloud call, that's cool - this is
         # an attempt to provide additional data and should not block forward
         # progress
@@ -498,7 +496,7 @@ def add_server_interfaces(cloud, server):
 def expand_server_security_groups(cloud, server):
     try:
         groups = cloud.list_server_security_groups(server)
-    except exc.OpenStackCloudException:
+    except exceptions.SDKException:
         groups = []
     server['security_groups'] = groups or []
 
@@ -550,7 +548,7 @@ def get_hostvars_from_server(cloud, server, mounts=None):
                 # Make things easier to consume elsewhere
                 volume['device'] = volume['attachments'][0]['device']
                 volumes.append(volume)
-        except exc.OpenStackCloudException:
+        except exceptions.SDKException:
             pass
     server_vars['volumes'] = volumes
     if mounts:
