@@ -9,6 +9,9 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+
+import typing as ty
+
 from openstack.common import tag
 from openstack import exceptions
 from openstack.image import _download
@@ -335,7 +338,7 @@ class Image(resource.Resource, tag.TagMixin, _download.DownloadMixin):
             stores = stores or []
 
         url = utils.urljoin(self.base_path, self.id, 'import')
-        data = {'method': {'name': method}}
+        data: ty.Dict[str, ty.Any] = {'method': {'name': method}}
 
         if uri:
             if method != 'web-download':
@@ -356,9 +359,8 @@ class Image(resource.Resource, tag.TagMixin, _download.DownloadMixin):
             data['all_stores'] = all_stores
         if all_stores_must_succeed is not None:
             data['all_stores_must_succeed'] = all_stores_must_succeed
-        for s in stores:
-            data.setdefault('stores', [])
-            data['stores'].append(s.id)
+        if stores:
+            data['stores'] = [s.id for s in stores]
 
         headers = {}
         # Backward compat
@@ -383,7 +385,7 @@ class Image(resource.Resource, tag.TagMixin, _download.DownloadMixin):
         base_path=None,
         **kwargs,
     ):
-        request = super(Image, self)._prepare_request(
+        request = super()._prepare_request(
             requires_id=requires_id,
             prepend_key=prepend_key,
             patch=patch,
@@ -401,7 +403,7 @@ class Image(resource.Resource, tag.TagMixin, _download.DownloadMixin):
     @classmethod
     def find(cls, session, name_or_id, ignore_missing=True, **params):
         # Do a regular search first (ignoring missing)
-        result = super(Image, cls).find(session, name_or_id, True, **params)
+        result = super().find(session, name_or_id, True, **params)
 
         if result:
             return result
@@ -416,6 +418,6 @@ class Image(resource.Resource, tag.TagMixin, _download.DownloadMixin):
 
         if ignore_missing:
             return None
-        raise exceptions.ResourceNotFound(
-            "No %s found for %s" % (cls.__name__, name_or_id)
+        raise exceptions.NotFoundException(
+            f"No {cls.__name__} found for {name_or_id}"
         )
