@@ -10,12 +10,14 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import typing as ty
+
 from openstack import resource
 from openstack.tests.functional import base
 
 
 class BaseSharedFileSystemTest(base.BaseFunctionalTest):
-    min_microversion = None
+    min_microversion: ty.Optional[str] = None
 
     def setUp(self):
         super().setUp()
