@@ -15,8 +15,6 @@ from unittest import mock
 
 import testtools
 
-import openstack
-import openstack.cloud
 from openstack import exceptions
 from openstack.network.v2 import network as _network
 from openstack.tests.unit import base
@@ -52,7 +50,7 @@ class TestNeutronExtensions(base.TestCase):
             ]
         )
         extensions = self.cloud._neutron_extensions()
-        self.assertEqual(set(['dvr', 'allowed-address-pairs']), extensions)
+        self.assertEqual({'dvr', 'allowed-address-pairs'}, extensions)
 
         self.assert_calls()
 
@@ -68,7 +66,7 @@ class TestNeutronExtensions(base.TestCase):
                 )
             ]
         )
-        with testtools.ExpectedException(exceptions.ResourceNotFound):
+        with testtools.ExpectedException(exceptions.NotFoundException):
             self.cloud._neutron_extensions()
 
         self.assert_calls()
@@ -468,7 +466,7 @@ class TestNetworks(base.TestCase):
     def test_create_network_wrong_availability_zone_hints_type(self):
         azh_opts = "invalid"
         with testtools.ExpectedException(
-            openstack.cloud.OpenStackCloudException,
+            exceptions.SDKException,
             "Parameter 'availability_zone_hints' must be a list",
         ):
             self.cloud.create_network(
@@ -478,7 +476,7 @@ class TestNetworks(base.TestCase):
     def test_create_network_provider_wrong_type(self):
         provider_opts = "invalid"
         with testtools.ExpectedException(
-            openstack.cloud.OpenStackCloudException,
+            exceptions.SDKException,
             "Parameter 'provider' must be a dict",
         ):
             self.cloud.create_network("netname", provider=provider_opts)
@@ -543,14 +541,14 @@ class TestNetworks(base.TestCase):
 
     def test_create_network_with_wrong_mtu_size(self):
         with testtools.ExpectedException(
-            openstack.cloud.OpenStackCloudException,
+            exceptions.SDKException,
             "Parameter 'mtu_size' must be greater than 67.",
         ):
             self.cloud.create_network("netname", mtu_size=42)
 
     def test_create_network_with_wrong_mtu_type(self):
         with testtools.ExpectedException(
-            openstack.cloud.OpenStackCloudException,
+            exceptions.SDKException,
             "Parameter 'mtu_size' must be an integer.",
         ):
             self.cloud.create_network("netname", mtu_size="fourty_two")
@@ -658,7 +656,7 @@ class TestNetworks(base.TestCase):
             ]
         )
         self.assertRaises(
-            openstack.cloud.OpenStackCloudException,
+            exceptions.SDKException,
             self.cloud.delete_network,
             network_name,
         )
