@@ -10,12 +10,14 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import http
 from unittest import mock
 
 from openstack.compute.v2 import flavor
 from openstack.compute.v2 import server
 from openstack.image.v2 import image
 from openstack.tests.unit import base
+from openstack.tests.unit import fakes
 
 IDENTIFIER = 'IDENTIFIER'
 EXAMPLE = {
@@ -112,7 +114,7 @@ EXAMPLE = {
 
 class TestServer(base.TestCase):
     def setUp(self):
-        super(TestServer, self).setUp()
+        super().setUp()
         self.resp = mock.Mock()
         self.resp.body = None
         self.resp.json = mock.Mock(return_value=self.resp.body)
@@ -166,6 +168,7 @@ class TestServer(base.TestCase):
                 "progress": "progress",
                 "project_id": "project_id",
                 "ramdisk_id": "ramdisk_id",
+                "pinned_availability_zone": "pinned_availability_zone",
                 "reservation_id": "reservation_id",
                 "root_device_name": "root_device_name",
                 "sort_dir": "sort_dir",
@@ -316,6 +319,33 @@ class TestServer(base.TestCase):
             microversion=self.sess.default_microversion,
         )
 
+    def test_get_password(self):
+        sot = server.Server(**EXAMPLE)
+        self.sess.get.return_value = fakes.FakeResponse(
+            data={'password': 'foo'}
+        )
+
+        result = sot.get_password(self.sess)
+        self.assertEqual('foo', result)
+
+        url = 'servers/IDENTIFIER/os-server-password'
+        self.sess.get.assert_called_with(
+            url, microversion=self.sess.default_microversion
+        )
+
+    def test_clear_password(self):
+        sot = server.Server(**EXAMPLE)
+        self.sess.delete.return_value = fakes.FakeResponse(
+            status_code=http.HTTPStatus.NO_CONTENT,
+        )
+
+        self.assertIsNone(sot.clear_password(self.sess))
+
+        url = 'servers/IDENTIFIER/os-server-password'
+        self.sess.delete.assert_called_with(
+            url, microversion=self.sess.default_microversion
+        )
+
     def test_reboot(self):
         sot = server.Server(**EXAMPLE)
 
@@ -353,14 +383,18 @@ class TestServer(base.TestCase):
 
         result = sot.rebuild(
             self.sess,
+            '123',
             name='noo',
             admin_password='seekr3t',
-            image='http://image/1',
+            preserve_ephemeral=False,
             access_ipv4="12.34.56.78",
             access_ipv6="fe80::100",
             metadata={"meta var": "meta val"},
             user_data="ZWNobyAiaGVsbG8gd29ybGQi",
-            preserve_ephemeral=False,
+            key_name='my-ecdsa-key',
+            description='an updated description',
+            trusted_image_certificates=['foo'],
+            hostname='new-hostname',
         )
 
         self.assertIsInstance(result, server.Server)
@@ -369,13 +403,17 @@ class TestServer(base.TestCase):
         body = {
             "rebuild": {
                 "name": "noo",
-                "imageRef": "http://image/1",
+                "imageRef": "123",
                 "adminPass": "seekr3t",
                 "accessIPv4": "12.34.56.78",
                 "accessIPv6": "fe80::100",
                 "metadata": {"meta var": "meta val"},
                 "user_data": "ZWNobyAiaGVsbG8gd29ybGQi",
                 "preserve_ephemeral": False,
+                "key_name": 'my-ecdsa-key',
+                "description": 'an updated description',
+                "trusted_image_certificates": ['foo'],
+                "hostname": "new-hostname",
             }
         }
         headers = {'Accept': ''}
@@ -393,9 +431,9 @@ class TestServer(base.TestCase):
 
         result = sot.rebuild(
             self.sess,
+            '123',
             name='nootoo',
             admin_password='seekr3two',
-            image='http://image/2',
         )
 
         self.assertIsInstance(result, server.Server)
@@ -404,7 +442,7 @@ class TestServer(base.TestCase):
         body = {
             "rebuild": {
                 "name": "nootoo",
-                "imageRef": "http://image/2",
+                "imageRef": "123",
                 "adminPass": "seekr3two",
             }
         }
@@ -416,6 +454,44 @@ class TestServer(base.TestCase):
             microversion=self.sess.default_microversion,
         )
 
+    def test_rebuild_none_values(self):
+        sot = server.Server(**EXAMPLE)
+        # Let the translate pass through, that portion is tested elsewhere
+        sot._translate_response = lambda arg: arg
+
+        result = sot.rebuild(
+            self.sess,
+            '123',
+            admin_password=None,
+            access_ipv4=None,
+            access_ipv6=None,
+            metadata=None,
+            user_data=None,
+            description=None,
+        )
+
+        self.assertIsInstance(result, server.Server)
+
+        url = 'servers/IDENTIFIER/action'
+        body = {
+            "rebuild": {
+                "imageRef": "123",
+                "adminPass": None,
+                "accessIPv4": None,
+                "accessIPv6": None,
+                "metadata": None,
+                "user_data": None,
+                "description": None,
+            }
+        }
+        headers = {'Accept': ''}
+        self.sess.post.assert_called_with(
+            url,
+            json=body,
+            headers=headers,
+            microversion=self.sess.default_microversion,
+        )
+
     def test_resize(self):
         sot = server.Server(**EXAMPLE)
 
@@ -904,7 +980,11 @@ class TestServer(base.TestCase):
         sot = server.Server(**EXAMPLE)
 
         res = sot.evacuate(
-            self.sess, host='HOST2', admin_pass='NEW_PASS', force=True
+            self.sess,
+            host='HOST2',
+            admin_pass='NEW_PASS',
+            force=True,
+            on_shared_storage=False,
         )
 
         self.assertIsNone(res)
@@ -914,6 +994,7 @@ class TestServer(base.TestCase):
                 'host': 'HOST2',
                 'adminPass': 'NEW_PASS',
                 'force': True,
+                'onSharedStorage': False,
             }
         }
         headers = {'Accept': ''}
